man = []
other = []
try:
    data = open('sch.txt')
    for each_line in data:
        try:
            (role,line_spoken) = each_line.split(':',1)
            line_spoken = line_spoken.split('\n ')
            if role == 'Man':
                man.append(line_spoken)
            elif role == 'Other Man':
                other.append(line_spoken)
        except ValueError:
            pass
    data.close()
except IOError:
    print('the data file is missing!')
print(man)
print(other)



from distutils.core import setup
setup(
	name='hcl_exception.py',
	version='1.0.0',
	py_modules=['hcl_exception'],
	author='wanliguhong',
	email='huchaoling0823@126.com',
	url='http://pypi.python.org/',
	description='char data.',
	)
